
# Slot: predicate


A high-level grouping for the relationship type. AKA minimal predicate. This is analogous to category for nodes.

URI: [biolink:pairwise_molecular_interaction_predicate](https://w3id.org/biolink/vocab/pairwise_molecular_interaction_predicate)


## Domain and Range

[PairwiseMolecularInteraction](PairwiseMolecularInteraction.md) &#8594;  <sub>1..1</sub> [PredicateType](types/PredicateType.md)

## Parents

 *  is_a: [pairwise gene to gene interaction➞predicate](pairwise_gene_to_gene_interaction_predicate.md)

## Children


## Used by

 * [PairwiseMolecularInteraction](PairwiseMolecularInteraction.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Local names:** | | annotation predicate (ga4gh) |
|  | | predicate (translator) |
| **Mappings:** | | rdf:predicate |
| **Exact Mappings:** | | owl:annotatedProperty |
|  | | OBAN:association_has_predicate |

